==> RSQLite_0.4-1.tar.gz: sqlite-3.2.8/www/support.tcl <==
set rcsid {$Id: support.tcl,v 1.5 2004/11/01 16:03:12 drh Exp $}
source common.tcl
header {SQLite Support Options}
puts {
<h2>SQLite Support Options</h2>


<h3>Mailing List</h3>
<p>
A mailing list has been set up for asking questions and
for open discussion of problems
and issues by the SQLite user community.
To subscribe to the mailing list, send an email to
<a href="mailto:sqlite-users-subscribe@sqlite.org">
sqlite-users-subscribe@sqlite.org</a>.
If you would prefer to get digests rather than individual
emails, send a message to to
<a href="mailto:sqlite-users-digest-subscribe@sqlite.org">
sqlite-users-digest-subscribe@sqlite.org</a>.
For additional information about operating and using this
mailing list, send a message to
<a href="mailto:sqlite-users-help@sqlite.org">
sqlite-users-help@sqlite.org</a> and instructions will be
sent by to you by return email.
</p>

<p>
There are multiple archives of the mailing list:
</p>

<blockquote>
<a href="http://www.mail-archive.com/sqlite-users%40sqlite.org/">
http://www.mail-archive.com/sqlite-users%40sqlite.org</a><br>
<a href="http://www.theaimsgroup.com/">
http://www.theaimsgroup.com/</a><br>
<a href="http://news.gmane.org/gmane.comp.db.sqlite.general">
http://news.gmane.org/gmane.comp.db.sqlite.general</a>
</blockquote>

</p>

<a name="directemail">
<h3>Direct E-Mail To The Author</h3>

<p>
Use the mailing list.
Please do <b>not</b> send email directly to the author of SQLite
unless:
<ul>
<li>You have or intend to acquire a professional support contract
as described below, or</li>
<li>You are working on an open source project.</li>
</ul>
You are welcomed to use SQLite in closed source, proprietary, and/or
commerical projects and to ask questions about such use on the public
mailing list.  But please do not ask to receive free direct technical
support.  The software is free; direct technical support is not.
</p>


<h3>Professional Support</h3>

<p>
If you would like professional support for SQLite
or if you want custom modifications to SQLite performed by the
original author, these services are available for a modest fee.
For additional information visit
<a href="http://www.hwaci.com/sw/sqlite/prosupport.html">
http://www.hwaci.com/sw/sqlite/prosupport.html</a> or contact:</p>

<blockquote>
D. Richard Hipp <br />
Hwaci - Applied Software Research <br />
704.948.4565 <br />
<a href="mailto:drh@hwaci.com">drh@hwaci.com</a>
</blockquote>

}
footer $rcsid

==> RSQLite_0.4-9.tar.gz: sqlite-3.3.8/www/support.tcl <==
set rcsid {$Id: support.tcl,v 1.6 2005/12/05 22:22:40 drh Exp $}
source common.tcl
header {SQLite Support Options}
puts {
<h2>SQLite Support Options</h2>


<h3>Mailing List</h3>
<p>
A mailing list has been set up for asking questions and
for open discussion of problems
and issues by the SQLite user community.
To subscribe to the mailing list, send an email to
<a href="mailto:sqlite-users-subscribe@sqlite.org">
sqlite-users-subscribe@sqlite.org</a>.
If you would prefer to get digests rather than individual
emails, send a message to to
<a href="mailto:sqlite-users-digest-subscribe@sqlite.org">
sqlite-users-digest-subscribe@sqlite.org</a>.
For additional information about operating and using this
mailing list, send a message to
<a href="mailto:sqlite-users-help@sqlite.org">
sqlite-users-help@sqlite.org</a> and instructions will be
sent by to you by return email.
</p>

<p>
There are multiple archives of the mailing list:
</p>

<blockquote>
<a href="http://www.mail-archive.com/sqlite-users%40sqlite.org/">
http://www.mail-archive.com/sqlite-users%40sqlite.org</a><br>
<a href="http://marc.10east.com/?l=sqlite-users&r=1&w=2">
http://marc.10east.com/?l=sqlite-users&r=1&w=2</a><br>
<a href="http://news.gmane.org/gmane.comp.db.sqlite.general">
http://news.gmane.org/gmane.comp.db.sqlite.general</a>
</blockquote>

</p>

<a name="directemail">
<h3>Direct E-Mail To The Author</h3>

<p>
Use the mailing list.
Please do <b>not</b> send email directly to the author of SQLite
unless:
<ul>
<li>You have or intend to acquire a professional support contract
as described below, or</li>
<li>You are working on an open source project.</li>
</ul>
You are welcomed to use SQLite in closed source, proprietary, and/or
commerical projects and to ask questions about such use on the public
mailing list.  But please do not ask to receive free direct technical
support.  The software is free; direct technical support is not.
</p>


<h3>Professional Support</h3>

<p>
If you would like professional support for SQLite
or if you want custom modifications to SQLite performed by the
original author, these services are available for a modest fee.
For additional information visit
<a href="http://www.hwaci.com/sw/sqlite/prosupport.html">
http://www.hwaci.com/sw/sqlite/prosupport.html</a> or contact:</p>

<blockquote>
D. Richard Hipp <br />
Hwaci - Applied Software Research <br />
704.948.4565 <br />
<a href="mailto:drh@hwaci.com">drh@hwaci.com</a>
</blockquote>

}
footer $rcsid
